*** Settings ***
Documentation     客户端-获取机构配置信息
...               SettingType 0-病人、1-检查、2-预约会诊
...               管理端机构>>更多>>病人配置、检查配置、预约会诊配置
Suite Setup
Resource          ../../../CommonConfig/Config.robot
Resource          ../../../AllApi/ClientAPI/PersonalInformationApi/CommonLoginAsync.robot
Resource          ../../../AllApi/ClientAPI/OrganizationInformationApi/GetOrganizationSettingAsync.robot

*** Variables ***

*** Test Cases ***
class_001_获取机构配置信息（病人），版本号小于最新版本
    [Template]
    #获取Token
    ${token}    GetCommonLoginAsyncToken    ${user_jo0221}[0]    ${EMPTY}    ${user_jo0221}[1]    ${3}    ${0}
    Log    ${token}
    #获取机构配置信息，病人、小于最新版本号
    ${res}    GetOrganizationSettingAsyncPost    ${token}    ${getOrganizationSettingAsync_settingType}[0]    0.1
    Log    ${res}
    ${content}    Get From Dictionary    ${res}    content
    #校验
    ${settingVersion}    Get From Dictionary    ${content}    SettingVersion
    Should Not Be Equal As Strings    ${settingVersion}    0.1

class_002_获取机构检查配置信息
    [Template]
    #获取Token
    ${token}    GetCommonLoginAsyncToken    ${user_jo0221}[0]    ${EMPTY}    ${user_jo0221}[1]    ${3}    ${0}
    Log    ${token}
    #获取机构配置信息，检查、小于最新版本号
    ${res}    GetOrganizationSettingAsyncPost    ${token}    ${getOrganizationSettingAsync_settingType}[1]    0.1
    Log    ${res}
    ${content}    Get From Dictionary    ${res}    content
    #校验
    ${settingVersion}    Get From Dictionary    ${content}    SettingVersion
    Should Not Be Equal As Strings    ${settingVersion}    0.1

class_003_获取机构预约会诊配置信息
    [Template]
    #获取Token
    ${token}    GetCommonLoginAsyncToken    ${user_jo0221}[0]    ${EMPTY}    ${user_jo0221}[1]    ${3}    ${0}
    Log    ${token}
    #获取机构配置信息，预约会诊、小于最新版本号
    ${res}    GetOrganizationSettingAsyncPost    ${token}    ${getOrganizationSettingAsync_settingType}[2]    0.1
    Log    ${res}
    ${content}    Get From Dictionary    ${res}    content
    #校验
    ${settingVersion}    Get From Dictionary    ${content}    SettingVersion
    Should Not Be Equal As Strings    ${settingVersion}    0.1

Exception_001_获取机构配置信息，Token传入空值
    [Template]
    #获取机构配置信息，Token传入空值
    ${res}    GetOrganizationSettingAsyncPost    ${EMPTY}    ${getOrganizationSettingAsync_settingType}[2]    0.1
    Log    ${res}
    #校验
    ${flag}    Result Analysis    ${res}    false    ${1}    Permission validation error
    Should Be True    ${flag}

Exception_002_获取机构配置信息，SettingType传入非特定值
    [Template]
    #获取Token
    ${token}    GetCommonLoginAsyncToken    ${user_jo0221}[0]    ${EMPTY}    ${user_jo0221}[1]    ${3}    ${0}
    #获取机构配置信息，SettingType传入非特定值
    ${res}    GetOrganizationSettingAsyncPost    ${token}    99    0.1
    Log    ${res}
    ${content}    Get From Dictionary    ${res}    content
    #校验
    ${settingVersion}    Get From Dictionary    ${content}    SettingVersion
    Should Be Empty    ${settingVersion}

Exception_003_获取机构配置信息，Version传入空值
    [Template]
    #获取Token
    ${token}    GetCommonLoginAsyncToken    ${user_jo0221}[0]    ${EMPTY}    ${user_jo0221}[1]    ${3}    ${0}
    Log    ${token}
    #获取机构配置信息，Version传入空值
    ${res}    GetOrganizationSettingAsyncPost    ${token}    ${getOrganizationSettingAsync_settingType}[0]    ${EMPTY}
    Log    ${res}
    ${content}    Get From Dictionary    ${res}    content
    #校验
    ${flag}    Result Analysis    ${res}    false    ${6039}    Not real version
    Should Be True    ${flag}

Exception_004_获取机构配置信息，Version大于或等于当前版本
    [Template]
    #获取Token
    ${token}    GetCommonLoginAsyncToken    ${user_jo0221}[0]    ${EMPTY}    ${user_jo0221}[1]    ${3}    ${0}
    Log    ${token}
    #获取机构配置信息，Version大于或等于当前版本
    ${res}    GetOrganizationSettingAsyncPost    ${token}    ${getOrganizationSettingAsync_settingType}[0]    9.9
    Log    ${res}
    ${content}    Get From Dictionary    ${res}    content
    #校验
    ${flag}    Result Analysis    ${res}    false    ${6041}    This is the latest version
    Should Be True    ${flag}

Exception_005_获取机构配置信息，Version规则校验
    [Documentation]    需满足规则^[0-9]{1}(.[0-9])+$，不能大于10
    [Template]
    #获取Token
    ${token}    GetCommonLoginAsyncToken    ${user_jo0221}[0]    ${EMPTY}    ${user_jo0221}[1]    ${3}    ${0}
    Log    ${token}
    #获取机构配置信息，Version不符合规则校验要求
    ${res}    GetOrganizationSettingAsyncPost    ${token}    ${getOrganizationSettingAsync_settingType}[0]    10
    Log    ${res}
    ${content}    Get From Dictionary    ${res}    content
    #校验
    ${flag}    Result Analysis    ${res}    false    ${6039}    Not real version
    Should Be True    ${flag}

*** Keywords ***
